@@ -3,18 +3,17 @@ try:
 except ImportError as e:
     from . import _write_py as _write
 
+# Private API
 SCHEMA_DEFS = _write.SCHEMA_DEFS
 acquaint_schema = _write.acquaint_schema
-dump = _write.dump
+WRITERS = _write.WRITERS
+
+# Public API
 writer = _write.writer
 Writer = _write.Writer
 schemaless_writer = _write.schemaless_writer
-write_data = _write.write_data
-
-_WRITERS = _write.WRITERS
 LOGICAL_WRITERS = _write.LOGICAL_WRITERS
 
 __all__ = [
-    'SCHEMA_DEFS', 'acquaint_schema', 'writer', 'schemaless_writer',
-    'write_data', 'LOGICAL_WRITERS',
+    'writer', 'Writer', 'schemaless_writer', 'LOGICAL_WRITERS',
 ]
